@@ -10,49 +10,49 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
-$VERSION = '0.18';
-$DATE = '2004/05/22';
+$VERSION = '0.19';
+$DATE = '2004/05/23';
 $FILE = __FILE__;
 
 use vars qw(%INVENTORY);
 %INVENTORY = (
-    'lib/Docs/Site_SVD/Test_STDmaker.pm' => [qw(0.18 2004/05/22), 'revised 0.17'],
-    'MANIFEST' => [qw(0.18 2004/05/22), 'generated, replaces 0.17'],
-    'Makefile.PL' => [qw(0.18 2004/05/22), 'generated, replaces 0.17'],
-    'README' => [qw(0.18 2004/05/22), 'generated, replaces 0.17'],
+    'lib/Docs/Site_SVD/Test_STDmaker.pm' => [qw(0.19 2004/05/23), 'revised 0.18'],
+    'MANIFEST' => [qw(0.19 2004/05/23), 'generated, replaces 0.18'],
+    'Makefile.PL' => [qw(0.19 2004/05/23), 'generated, replaces 0.18'],
+    'README' => [qw(0.19 2004/05/23), 'generated, replaces 0.18'],
     'lib/Test/STDmaker.pm' => [qw(1.19 2004/05/22), 'unchanged'],
     'lib/Test/STDmaker/Check.pm' => [qw(1.14 2004/05/22), 'unchanged'],
     'lib/Test/STDmaker/Demo.pm' => [qw(1.14 2004/05/21), 'unchanged'],
     'lib/Test/STDmaker/STD.pm' => [qw(1.11 2004/05/21), 'unchanged'],
     'lib/Test/STDmaker/Verify.pm' => [qw(1.15 2004/05/22), 'unchanged'],
     'lib/Test/STD/PerlSTD.pm' => [qw(1.08 2004/05/19), 'unchanged'],
-    't/Test/STDmaker/STDmaker.d' => [qw(0.15 2004/05/22), 'revised 0.14'],
-    't/Test/STDmaker/STDmaker.pm' => [qw(0.13 2004/05/22), 'revised 0.12'],
-    't/Test/STDmaker/STDmaker.t' => [qw(0.15 2004/05/22), 'revised 0.14'],
+    't/Test/STDmaker/STDmaker.d' => [qw(0.16 2004/05/23), 'revised 0.15'],
+    't/Test/STDmaker/STDmaker.pm' => [qw(0.14 2004/05/23), 'revised 0.13'],
+    't/Test/STDmaker/STDmaker.t' => [qw(0.16 2004/05/23), 'revised 0.15'],
     't/Test/STDmaker/tg0.pm' => [qw(0.03 2004/04/09), 'unchanged'],
-    't/Test/STDmaker/tg2A.pm' => [qw(0.05 2004/05/22), 'revised 0.04'],
-    't/Test/STDmaker/tg2B.pm' => [qw(0.06 2004/05/22), 'revised 0.05'],
-    't/Test/STDmaker/tgA0.pm' => [qw(0.07 2004/05/22), 'revised 0.06'],
-    't/Test/STDmaker/tgA1.pm' => [qw(0.06 2004/05/22), 'new'],
-    't/Test/STDmaker/tgA2.pm' => [qw(0.08 2004/05/22), 'revised 0.07'],
-    't/Test/STDmaker/tgA2A2.txt' => [qw(0.12 2004/05/22), 'revised 0.11'],
-    't/Test/STDmaker/tgA2A3.txt' => [qw(0.12 2004/05/22), 'revised 0.11'],
-    't/Test/STDmaker/tgA2B.txt' => [qw(0.09 2004/05/22), 'revised 0.08'],
-    't/Test/STDmaker/tgA2C.txt' => [qw(0.1 2004/05/22), 'revised 0.09'],
+    't/Test/STDmaker/tg2A.pm' => [qw(0.03 2004/05/22), 'unchanged'],
+    't/Test/STDmaker/tg2B.pm' => [qw(0.03 2004/05/22), 'unchanged'],
+    't/Test/STDmaker/tgA0.pm' => [qw(0.06 2004/05/22), 'unchanged'],
+    't/Test/STDmaker/tgA1.pm' => [qw(0.06 2004/05/22), 'unchanged'],
+    't/Test/STDmaker/tgA2.pm' => [qw(0.01 2004/05/22), 'unchanged'],
+    't/Test/STDmaker/tgA2A2.txt' => [qw(0.12 2004/05/22), 'unchanged'],
+    't/Test/STDmaker/tgA2A3.txt' => [qw(0.12 2004/05/22), 'unchanged'],
+    't/Test/STDmaker/tgA2B.txt' => [qw(0.09 2004/05/22), 'unchanged'],
+    't/Test/STDmaker/tgA2C.txt' => [qw(0.1 2004/05/22), 'unchanged'],
     't/Test/STDmaker/tgB0.pm' => [qw(0.02 2004/05/18), 'unchanged'],
-    't/Test/STDmaker/tgB1.pm' => [qw(0.01 2004/05/22), 'new'],
+    't/Test/STDmaker/tgB1.pm' => [qw(0.01 2004/05/22), 'unchanged'],
     't/Test/STDmaker/tgB2.pm' => [qw(0.03 2004/05/21), 'unchanged'],
     't/Test/STDmaker/tgB2.txt' => [qw(0.09 2004/05/14), 'unchanged'],
     't/Test/STDmaker/tgC0.pm' => [qw(0.04 2004/05/18), 'unchanged'],
-    't/Test/STDmaker/tgC1.pm' => [qw(0.01 2004/05/22), 'new'],
+    't/Test/STDmaker/tgC1.pm' => [qw(0.01 2004/05/22), 'unchanged'],
     't/Test/STDmaker/tgC2.pm' => [qw(0.05 2004/05/21), 'unchanged'],
-    't/Test/STDmaker/tgD0.pm' => [qw(0.06 2004/05/22), 'new'],
-    't/Test/STDmaker/tmake.pl' => [qw(1.06 2004/05/22), 'unchanged'],
-    't/Test/STDmaker/Text/Scrub.pm' => [qw(1.14 2004/05/22), 'unchanged'],
-    't/Test/STDmaker/Test/Tech.pm' => [qw(1.26 2004/05/22), 'unchanged'],
-    't/Test/STDmaker/Data/Secs2.pm' => [qw(1.26 2004/05/22), 'unchanged'],
-    't/Test/STDmaker/Data/Str2Num.pm' => [qw(0.08 2004/05/22), 'unchanged'],
-    't/Test/STDmaker/Data/Startup.pm' => [qw(0.07 2004/05/22), 'unchanged'],
+    't/Test/STDmaker/tgD0.pm' => [qw(0.06 2004/05/22), 'unchanged'],
+    't/Test/STDmaker/tmake.pl' => [qw(1.06 2004/05/23), 'unchanged'],
+    't/Test/STDmaker/Text/Scrub.pm' => [qw(1.14 2004/05/23), 'unchanged'],
+    't/Test/STDmaker/Test/Tech.pm' => [qw(1.26 2004/05/23), 'unchanged'],
+    't/Test/STDmaker/Data/Secs2.pm' => [qw(1.26 2004/05/23), 'unchanged'],
+    't/Test/STDmaker/Data/Str2Num.pm' => [qw(0.08 2004/05/23), 'unchanged'],
+    't/Test/STDmaker/Data/Startup.pm' => [qw(0.07 2004/05/23), 'unchanged'],
 
 );
 
@@ -85,9 +85,9 @@ Docs::Site_SVD::Test_STDmaker - generate test scripts, demo scripts from a test
 
  Revision: Q
 
- Version: 0.18
+ Version: 0.19
 
- Date: 2004/05/22
+ Date: 2004/05/23
 
  Prepared for: General Public 
 
@@ -176,7 +176,7 @@ further detail on the text database fields and the processing.
 
 =head2 1.3 Document overview.
 
-This document releases Test::STDmaker version 0.18
+This document releases Test::STDmaker version 0.19
 providing description of the inventory, installation
 instructions and other information necessary to
 utilize and track this release.
@@ -191,7 +191,7 @@ system file specification.
 
 This document releases the file 
 
- Test-STDmaker-0.18.tar.gz
+ Test-STDmaker-0.19.tar.gz
 
 found at the following repository(s):
 
@@ -278,43 +278,43 @@ consists of the following files:
 
  file                                                         version date       comment
  ------------------------------------------------------------ ------- ---------- ------------------------
- lib/Docs/Site_SVD/Test_STDmaker.pm                           0.18    2004/05/22 revised 0.17
- MANIFEST                                                     0.18    2004/05/22 generated, replaces 0.17
- Makefile.PL                                                  0.18    2004/05/22 generated, replaces 0.17
- README                                                       0.18    2004/05/22 generated, replaces 0.17
+ lib/Docs/Site_SVD/Test_STDmaker.pm                           0.19    2004/05/23 revised 0.18
+ MANIFEST                                                     0.19    2004/05/23 generated, replaces 0.18
+ Makefile.PL                                                  0.19    2004/05/23 generated, replaces 0.18
+ README                                                       0.19    2004/05/23 generated, replaces 0.18
  lib/Test/STDmaker.pm                                         1.19    2004/05/22 unchanged
  lib/Test/STDmaker/Check.pm                                   1.14    2004/05/22 unchanged
  lib/Test/STDmaker/Demo.pm                                    1.14    2004/05/21 unchanged
  lib/Test/STDmaker/STD.pm                                     1.11    2004/05/21 unchanged
  lib/Test/STDmaker/Verify.pm                                  1.15    2004/05/22 unchanged
  lib/Test/STD/PerlSTD.pm                                      1.08    2004/05/19 unchanged
- t/Test/STDmaker/STDmaker.d                                   0.15    2004/05/22 revised 0.14
- t/Test/STDmaker/STDmaker.pm                                  0.13    2004/05/22 revised 0.12
- t/Test/STDmaker/STDmaker.t                                   0.15    2004/05/22 revised 0.14
+ t/Test/STDmaker/STDmaker.d                                   0.16    2004/05/23 revised 0.15
+ t/Test/STDmaker/STDmaker.pm                                  0.14    2004/05/23 revised 0.13
+ t/Test/STDmaker/STDmaker.t                                   0.16    2004/05/23 revised 0.15
  t/Test/STDmaker/tg0.pm                                       0.03    2004/04/09 unchanged
- t/Test/STDmaker/tg2A.pm                                      0.05    2004/05/22 revised 0.04
- t/Test/STDmaker/tg2B.pm                                      0.06    2004/05/22 revised 0.05
- t/Test/STDmaker/tgA0.pm                                      0.07    2004/05/22 revised 0.06
- t/Test/STDmaker/tgA1.pm                                      0.06    2004/05/22 new
- t/Test/STDmaker/tgA2.pm                                      0.08    2004/05/22 revised 0.07
- t/Test/STDmaker/tgA2A2.txt                                   0.12    2004/05/22 revised 0.11
- t/Test/STDmaker/tgA2A3.txt                                   0.12    2004/05/22 revised 0.11
- t/Test/STDmaker/tgA2B.txt                                    0.09    2004/05/22 revised 0.08
- t/Test/STDmaker/tgA2C.txt                                    0.1     2004/05/22 revised 0.09
+ t/Test/STDmaker/tg2A.pm                                      0.03    2004/05/22 unchanged
+ t/Test/STDmaker/tg2B.pm                                      0.03    2004/05/22 unchanged
+ t/Test/STDmaker/tgA0.pm                                      0.06    2004/05/22 unchanged
+ t/Test/STDmaker/tgA1.pm                                      0.06    2004/05/22 unchanged
+ t/Test/STDmaker/tgA2.pm                                      0.01    2004/05/22 unchanged
+ t/Test/STDmaker/tgA2A2.txt                                   0.12    2004/05/22 unchanged
+ t/Test/STDmaker/tgA2A3.txt                                   0.12    2004/05/22 unchanged
+ t/Test/STDmaker/tgA2B.txt                                    0.09    2004/05/22 unchanged
+ t/Test/STDmaker/tgA2C.txt                                    0.1     2004/05/22 unchanged
  t/Test/STDmaker/tgB0.pm                                      0.02    2004/05/18 unchanged
- t/Test/STDmaker/tgB1.pm                                      0.01    2004/05/22 new
+ t/Test/STDmaker/tgB1.pm                                      0.01    2004/05/22 unchanged
  t/Test/STDmaker/tgB2.pm                                      0.03    2004/05/21 unchanged
  t/Test/STDmaker/tgB2.txt                                     0.09    2004/05/14 unchanged
  t/Test/STDmaker/tgC0.pm                                      0.04    2004/05/18 unchanged
- t/Test/STDmaker/tgC1.pm                                      0.01    2004/05/22 new
+ t/Test/STDmaker/tgC1.pm                                      0.01    2004/05/22 unchanged
  t/Test/STDmaker/tgC2.pm                                      0.05    2004/05/21 unchanged
- t/Test/STDmaker/tgD0.pm                                      0.06    2004/05/22 new
- t/Test/STDmaker/tmake.pl                                     1.06    2004/05/22 unchanged
- t/Test/STDmaker/Text/Scrub.pm                                1.14    2004/05/22 unchanged
- t/Test/STDmaker/Test/Tech.pm                                 1.26    2004/05/22 unchanged
- t/Test/STDmaker/Data/Secs2.pm                                1.26    2004/05/22 unchanged
- t/Test/STDmaker/Data/Str2Num.pm                              0.08    2004/05/22 unchanged
- t/Test/STDmaker/Data/Startup.pm                              0.07    2004/05/22 unchanged
+ t/Test/STDmaker/tgD0.pm                                      0.06    2004/05/22 unchanged
+ t/Test/STDmaker/tmake.pl                                     1.06    2004/05/23 unchanged
+ t/Test/STDmaker/Text/Scrub.pm                                1.14    2004/05/23 unchanged
+ t/Test/STDmaker/Test/Tech.pm                                 1.26    2004/05/23 unchanged
+ t/Test/STDmaker/Data/Secs2.pm                                1.26    2004/05/23 unchanged
+ t/Test/STDmaker/Data/Str2Num.pm                              0.08    2004/05/23 unchanged
+ t/Test/STDmaker/Data/Startup.pm                              0.07    2004/05/23 unchanged
 
 
 =head2 3.3 Changes
@@ -629,6 +629,30 @@ Backed out test descriptions that producde curly brackets except for C<BEGIN> an
 blocks of generated scripts. Added a warn($diag) to see if get diagnostic messages.
 The backed test descriptions can be added as another test once get some green PASSES.
 
+=item Test-STDmaker-0.19
+
+Test Failure:
+
+ Subject: FAIL Test-STDmaker-0.18 i386-netbsd 1.6 
+ From: alian@cpan.org (Cpan Tester - CPAN++ Automate ) 
+
+ "my" variable $expected1 masks earlier declaration in same scope at tgA1.d line 203.
+ "my" variable $x masks earlier declaration in same scope at tgA1.d line 228.
+ "my" variable $y masks earlier declaration in same scope at tgA1.d line 233.
+ "my" variable $expected1 masks earlier declaration in same scope at tgA1.t line 240.
+ "my" variable $x masks earlier declaration in same scope at tgA1.t line 252.
+ "my" variable $y masks earlier declaration in same scope at tgA1.t line 257.
+
+Analysis:
+
+Test failure different. Got diagnostic warn that shows Check temp.pl looks ok.
+The above failures do not correspond to files generated for Microsoft. 
+
+Debug:
+
+Put in warns to take look at generated files. So remotely debugging with print 
+statement.
+
 =back
 
 =head2 3.4 Adaptation data.
@@ -667,13 +691,13 @@ Enter one of the following repositories in a web browser:
   http://www.softwarediamonds/packages/
   http://www.perl.com/CPAN/authors/id/S/SO/SOFTDIA/
 
-Right click on 'Test-STDmaker-0.18.tar.gz' and download to a temporary
+Right click on 'Test-STDmaker-0.19.tar.gz' and download to a temporary
 installation directory.
 Enter the following where $make is 'nmake' for microsoft
 windows; otherwise 'make'.
 
- gunzip Test-STDmaker-0.18.tar.gz
- tar -xf Test-STDmaker-0.18.tar
+ gunzip Test-STDmaker-0.19.tar.gz
+ tar -xf Test-STDmaker-0.19.tar
  perl Makefile.PL
  $make test
  $make install
@@ -804,20 +828,7 @@ Software Version Description
 =back
 
 =for html
-<hr>
-<p><br>
-<!-- BLK ID="PROJECT_MANAGEMENT" -->
-<!-- /BLK -->
-<p><br>
-<!-- BLK ID="NOTICE" -->
-<!-- /BLK -->
-<p><br>
-<!-- BLK ID="OPT-IN" -->
-<!-- /BLK -->
-<p><br>
-<!-- BLK ID="LOG_CGI" -->
-<!-- /BLK -->
-<p><br>
+
 
 =cut
 
@@ -828,9 +839,9 @@ __DATA__
 DISTNAME: Test-STDmaker^
 REPOSITORY_DIR: packages^
 
-VERSION : 0.18^
-FREEZE: 0^
-PREVIOUS_RELEASE: 0.17^
+VERSION : 0.19^
+FREEZE: 1^
+PREVIOUS_RELEASE: 0.18^
 REVISION: Q^
 
 PREVIOUS_DISTNAME:  ^
@@ -1267,6 +1278,30 @@ Backed out test descriptions that producde curly brackets except for C<BEGIN> an
 blocks of generated scripts. Added a warn($diag) to see if get diagnostic messages.
 The backed test descriptions can be added as another test once get some green PASSES.
 
+\=item Test-STDmaker-0.19
+
+Test Failure:
+
+ Subject: FAIL Test-STDmaker-0.18 i386-netbsd 1.6 
+ From: alian@cpan.org (Cpan Tester - CPAN++ Automate ) 
+
+ "my" variable $expected1 masks earlier declaration in same scope at tgA1.d line 203.
+ "my" variable $x masks earlier declaration in same scope at tgA1.d line 228.
+ "my" variable $y masks earlier declaration in same scope at tgA1.d line 233.
+ "my" variable $expected1 masks earlier declaration in same scope at tgA1.t line 240.
+ "my" variable $x masks earlier declaration in same scope at tgA1.t line 252.
+ "my" variable $y masks earlier declaration in same scope at tgA1.t line 257.
+
+Analysis:
+
+Test failure different. Got diagnostic warn that shows Check temp.pl looks ok.
+The above failures do not correspond to files generated for Microsoft. 
+
+Debug:
+
+Put in warns to take look at generated files. So remotely debugging with print 
+statement.
+
 \=back
 
 ^
@@ -1462,22 +1497,7 @@ SEE_ALSO:
 
 ^
 
-HTML:
-<hr>
-<p><br>
-<!-- BLK ID="PROJECT_MANAGEMENT" -->
-<!-- /BLK -->
-<p><br>
-<!-- BLK ID="NOTICE" -->
-<!-- /BLK -->
-<p><br>
-<!-- BLK ID="OPT-IN" -->
-<!-- /BLK -->
-<p><br>
-<!-- BLK ID="LOG_CGI" -->
-<!-- /BLK -->
-<p><br>
-^
+HTML: ^
 ~-~
 
 
@@ -1532,6 +1552,8 @@ HTML:
 
 
 
+
+
 
 
 
