@@ -10,8 +10,8 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
-$VERSION = '0.05';
-$DATE = '2004/05/18';
+$VERSION = '0.07';
+$DATE = '2004/05/22';
 $FILE = __FILE__;
 
 __DATA__
@@ -45,17 +45,6 @@ QC: my $expected1 = 'hello world'; ^
  A: 'hello world'^
  E: $expected1^
 
- N: ok subroutine^
-TS: \&tolerance^
- A: 99^
- E: [100, 10]^
-
- N: skip subroutine^
- S: 0^
-TS: \&tolerance^
- A: 80 ^
- E: [100, 10] ^
-
  N: Pass test^
  R: L<Test::STDmaker::tg1/capability-A [1]>^
  C: my $x = 2^
@@ -97,25 +86,6 @@ VO: ^
  A: $x^
  E: $x^
 
- N: Test loop^
- C:
-    my @expected = ('200','201','202');
-    my $i;
-    for( $i=0; $i < 3; $i++) {
- ^
-
- A: $i+200^
- R: L<Test::STDmaker::tg1/capability-C [1]>^
- E: $expected[$i]^
-
- A: $i + ($x * 100)^
- R: L<Test::STDmaker::tg1/capability-B [4]>^
- E: $expected[$i]^
-
-C:
-    }; 
-^
-
  N: Failed test that skips the rest^
  R: L<Test::STDmaker::tg1/capability-B [2]>^
  A: $x + $y^
@@ -137,18 +107,6 @@ SE: 6^
  A: $x + $y + $x + $y + $x^
  E: 10^
 
-QC:
-    sub tolerance
-    {   
-        my ($actual,$expected) = @_;
-        my ($average, $tolerance) = @$expected;
-        use integer;
-        $actual = (($average - $actual) * 100) / $average;
-        no integer;
-        (-$tolerance < $actual) && ($actual < $tolerance) ? 1 : 0;
-    }
-^
-
 See_Also: L<Test::STDmaker::tg1> ^
 
 Copyright: This STD is public domain.^
